==> haskell-network-multicast-0.2.0-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network-multicast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-multicast
version: 0.2.0
id: network-multicast-0.2.0-fIaMiUquhHBw6zChTG9on
key: network-multicast-0.2.0-fIaMiUquhHBw6zChTG9on
license: LicenseRef-PublicDomain
copyright: 2008-2016 Audrey Tang
maintainer: Marco Zocca
author: Audrey Tang <audreyt@audreyt.org>
stability: experimental
synopsis: Simple multicast library
description:
    The "Network.Multicast" module is for sending
    UDP datagrams over multicast (class D) addresses.
category: Network
abi: da484c4fee3e08c9c6b7189f7b6eddbf
exposed: True
exposed-modules:
    Network.Multicast
import-dirs: /usr/lib/ghc-8.4.3/site-local/network-multicast-0.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/network-multicast-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/network-multicast-0.2.0
hs-libraries: HSnetwork-multicast-0.2.0-fIaMiUquhHBw6zChTG9on
depends:
    base-4.11.1.0 network-2.7.0.1-4JbsvGgupC8D8OEac3vD1v
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             network-2.7.0.1-4JbsvGgupC8D8OEac3vD1v=9f1a3e2a2d1ba200f0b4b28f3589f138
haddock-interfaces: /usr/share/doc/haskell-network-multicast/html/network-multicast.haddock
haddock-html: /usr/share/doc/haskell-network-multicast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-multicast-0.2.0-32-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network-multicast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-multicast
version: 0.2.0
id: network-multicast-0.2.0-EhikVhHrS5bDnaewz15CwJ
key: network-multicast-0.2.0-EhikVhHrS5bDnaewz15CwJ
license: LicenseRef-PublicDomain
copyright: 2008-2016 Audrey Tang
maintainer: Marco Zocca
author: Audrey Tang <audreyt@audreyt.org>
stability: experimental
synopsis: Simple multicast library
description:
    The "Network.Multicast" module is for sending
    UDP datagrams over multicast (class D) addresses.
category: Network
abi: 7268eabd6c29dbc44a79da2631ef7aa2
exposed: True
exposed-modules:
    Network.Multicast
import-dirs: /usr/lib/ghc-8.4.3/site-local/network-multicast-0.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/network-multicast-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/network-multicast-0.2.0
hs-libraries: HSnetwork-multicast-0.2.0-EhikVhHrS5bDnaewz15CwJ
depends:
    base-4.11.1.0 network-2.7.0.2-3zQTN3hKcaz6IkeyUSsRrW
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             network-2.7.0.2-3zQTN3hKcaz6IkeyUSsRrW=69b658fb7f59eb9acbefe047d83e7e11
haddock-interfaces: /usr/share/doc/haskell-network-multicast/html/network-multicast.haddock
haddock-html: /usr/share/doc/haskell-network-multicast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
